<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Показати у програмі для керування файлами</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Спорожнити журнал</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Освіжити</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Ви певні, що хочете спорожнити журнал?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Підтвердити</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Всі</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Сьогодні</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 дні</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 тиждень</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 місяць</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 місяці</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Експортувати</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Всі</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Критичне становище</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Попередження</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Критична помилка</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Помилка</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Попередження</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Зауваження</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Інформація</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Діагностика</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Вхід</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Завантаження</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Вимикання</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Надкритична</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Трасування</translation>
    </message>
    <message>
        <source>Identity authentication</source>
        <translation>Розпізнавання профілю</translation>
    </message>
    <message>
        <source>Discretionary Access Control</source>
        <translation>Дискреційне керування доступом</translation>
    </message>
    <message>
        <source>Mandatory access control</source>
        <translation>Обов&apos;язкове керування доступом</translation>
    </message>
    <message>
        <source>Remote</source>
        <translation>Віддалений</translation>
    </message>
    <message>
        <source>Document audit</source>
        <translation>Ревізування документів</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Інше</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>zip(*.zip)</source>
        <translation>zip(*.zip)</translation>
    </message>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>текст (*.txt);; doc (*.doc);; xls (*.xls);; HTML (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Експортуємо…</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Успішно експортовано</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Не вдалося експортувати</translation>
    </message>
    <message>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation>Каталог експортування даних є недоступним. Будь ласка, виберіть інший каталог для дії з експортування.</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Експортування до файла</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Період:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Рівень: </translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Стан:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Тип події:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Користувач:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Дія:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Користувач:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Запис завантаження</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Запис вимикання</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Запис входу</translation>
    </message>
    <message>
        <source>Audit Type:</source>
        <translation>Тип нагляду:</translation>
    </message>
    <message>
        <source>Application:</source>
        <translation>Програма:</translation>
    </message>
    <message>
        <source>Submodule:</source>
        <translation>Підмодуль:</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Попередження</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Діагностика</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Інформація</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Помилка</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Критичне становище</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Попередження</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Критична помилка</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Зауваження</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Трасування</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Надкритична</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Файл журналу є порожнім</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Перегляд журналів</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Переглядач журналу — корисний інструмент для перегляду журналів системи.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Нічого не знайдено</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Пошук</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Рівень</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Процес</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Дата і час</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Інформація</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Користувач</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Джерело</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Дія</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Стан</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Тип події</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Користувач</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Рівень:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Процес:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Дата і час:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Інформація:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Порожньо</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Користувач:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation>Назва файла</translation>
    </message>
    <message>
        <source>Time Modified</source>
        <translation>Час внесення змін</translation>
    </message>
    <message>
        <source>SIG</source>
        <translation>SIG</translation>
    </message>
    <message>
        <source>EXE</source>
        <translation>EXE</translation>
    </message>
    <message>
        <source>Core File</source>
        <translation>Основний файл</translation>
    </message>
    <message>
        <source>User Name </source>
        <translation>Ім&apos;я користувача</translation>
    </message>
    <message>
        <source>Offset</source>
        <translation>Зсув</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Дата і час</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Журнал системи</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Журнал ядра</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Журнал завантаження</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Журнал dpkg</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Журнал KWin</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Журнал Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Журнал програм</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Подія завантаження-вимикання</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>Журнал dnf</translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation>Інший журнал</translation>
    </message>
    <message>
        <source>Custom Log</source>
        <translation>Нетиповий журнал</translation>
    </message>
    <message>
        <source>Audit Log</source>
        <translation>Журнал нагляду</translation>
    </message>
    <message>
        <source>Coredump Log</source>
        <translation>Журнал дампу ядра</translation>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation>Не вдалося отримати дані щодо аварії. Будь ласка, встановіть systemd-coredump.</translation>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation>У вас немає прав доступу для перегляду</translation>
    </message>
    <message>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation>Рівень захисту поточної системи: високий
 журнал ревізії можуть переглядати лише адміністратори-ревізори</translation>
    </message>
    <message>
        <source>Audit log is not exist.</source>
        <translation>Журналу ревізії не існує.</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Export logs to the specified path</source>
        <translation>Експортувати журнал до вказаного каталогу</translation>
    </message>
    <message>
        <source>PATH</source>
        <translation>ШЛЯХ</translation>
    </message>
    <message>
        <source>Export logs of specified types</source>
        <translation>Експортувати журнали вказаних типів</translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation>ТИП</translation>
    </message>
    <message>
        <source>Export logs of specified self-developed applications</source>
        <translation>Експортувати журнали вказаних самостійно розроблених програм</translation>
    </message>
    <message>
        <source>SELF APPNAME</source>
        <translation>НАЗВА ПРОГРАМИ</translation>
    </message>
    <message>
        <source>Export logs within a specified time period</source>
        <translation>Експортувати журнал за вказаний період часу</translation>
    </message>
    <message>
        <source>PERIOD</source>
        <translation>ПЕРІОД</translation>
    </message>
    <message>
        <source>Export logs within a specified debug level</source>
        <translation>Експортувати журнали на вказаному рівні діагностики</translation>
    </message>
    <message>
        <source>LEVEL</source>
        <translation>РІВЕНЬ</translation>
    </message>
    <message>
        <source>BOOT STATUS</source>
        <translation>СТАН ЗАВАНТАЖЕННЯ</translation>
    </message>
    <message>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation>Експортувати журнал завантаження за вказаним станом</translation>
    </message>
    <message>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation>Експортувати журнал boot-shutdown-event або ревізій для вказаного типу подій</translation>
    </message>
    <message>
        <source>EVENT TYPE</source>
        <translation>ТИП ПОДІЙ</translation>
    </message>
    <message>
        <source>Export logs based on keywords search results</source>
        <translation>Експортувати журнал на основі результатів пошуку за ключовим словом</translation>
    </message>
    <message>
        <source>KEY WORD</source>
        <translation>КЛЮЧОВЕ СЛОВО</translation>
    </message>
    <message>
        <source>Report coredump informations.</source>
        <translation>Повідомити дані дампів ядра.</translation>
    </message>
    <message>
        <source>Export logs based on app submodel</source>
        <translation>Експортувати журнал для підмодуля програм</translation>
    </message>
    <message>
        <source>SUBMODULE</source>
        <translation>ПІДМОДУЛЬ</translation>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation>Інтервал оновлення</translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation>10 сек.</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>1 хв.</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation>5 хв.</translation>
    </message>
    <message>
        <source>No refresh</source>
        <translation>Без оновлення</translation>
    </message>
    <message>
        <source>Export All</source>
        <translation>Експортувати усе</translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation>Оновити зараз</translation>
    </message>
</context>
</TS>